@@ -32,20 +32,21 @@
 #include <cstdint>
 #include <sstream>
 #include <string>
+#include <vector>
 
 #include "base/logging.h"
-#include "base/port.h"
 #include "base/singleton.h"
 #include "base/util.h"
 #include "dictionary/dictionary_token.h"
+#include "dictionary/system/codec_interface.h"
 #include "dictionary/system/words_info.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace dictionary {
 namespace {
-void EncodeDecodeKeyImpl(const absl::string_view src, std::string *dst);
-size_t GetEncodedDecodedKeyLengthImpl(const absl::string_view src);
+void EncodeDecodeKeyImpl(absl::string_view src, std::string *dst);
+size_t GetEncodedDecodedKeyLengthImpl(absl::string_view src);
 
 uint8_t GetFlagsForToken(const std::vector<TokenInfo> &tokens, int index);
 
@@ -92,7 +93,7 @@ constexpr int kValueTrieIdMax = 0x3fffff;
 // Unused for now.
 // We are using from 0x00~0xfa for the Kanji, Hiragana and Katakana.
 // Please see the comments for EncodeValue for details.
-// const uint8 kValueCharMarkReserved = 0xfb;
+// const uint8_t kValueCharMarkReserved = 0xfb;
 // ASCII character.
 constexpr uint8_t kValueCharMarkAscii = 0xfc;
 // UCS4 character 0x??00.
@@ -196,23 +197,19 @@ constexpr uint8_t kUpperCrammedIDMask = 0x3f;
 constexpr uint8_t kLastTokenFlag = 0x80;
 }  // namespace
 
-SystemDictionaryCodec::SystemDictionaryCodec() {}
-
-SystemDictionaryCodec::~SystemDictionaryCodec() {}
-
-const std::string SystemDictionaryCodec::GetSectionNameForKey() const {
+std::string SystemDictionaryCodec::GetSectionNameForKey() const {
   return kKeySectionName;
 }
 
-const std::string SystemDictionaryCodec::GetSectionNameForValue() const {
+std::string SystemDictionaryCodec::GetSectionNameForValue() const {
   return kValueSectionName;
 }
 
-const std::string SystemDictionaryCodec::GetSectionNameForTokens() const {
+std::string SystemDictionaryCodec::GetSectionNameForTokens() const {
   return kTokensSectionName;
 }
 
-const std::string SystemDictionaryCodec::GetSectionNameForPos() const {
+std::string SystemDictionaryCodec::GetSectionNameForPos() const {
   return kPosSectionName;
 }
 
@@ -252,7 +249,7 @@ void SystemDictionaryCodec::EncodeValue(const absl::string_view src,
                                         std::string *dst) const {
   DCHECK(dst);
   for (ConstChar32Iterator iter(src); !iter.Done(); iter.Next()) {
-    static_assert(sizeof(uint32_t) == sizeof(char32),
+    static_assert(sizeof(uint32_t) == sizeof(char32_t),
                   "char32 must be 32-bit integer size.");
     const uint32_t c = iter.Get();
     if (c >= 0x3041 && c < 0x3095) {
@@ -277,7 +274,7 @@ void SystemDictionaryCodec::EncodeValue(const absl::string_view src,
       dst->push_back(h);
       dst->push_back(c & 255);
     } else if (0x10000 <= c && c <= 0x10ffff) {
-      // charaters encoded into 2-4bytes.
+      // characters encoded into 2-4bytes.
       int left = ((c >> 16) & 255);
       const int middle = ((c >> 8) & 255);
       const int right = (c & 255);
@@ -489,7 +486,7 @@ namespace {
 // U+0020 - U+003F are left intact to represent numbers and hyphen in 1 byte.
 void EncodeDecodeKeyImpl(const absl::string_view src, std::string *dst) {
   for (ConstChar32Iterator iter(src); !iter.Done(); iter.Next()) {
-    static_assert(sizeof(uint32_t) == sizeof(char32),
+    static_assert(sizeof(uint32_t) == sizeof(char32_t),
                   "char32 must be 32-bit integer size.");
     uint32_t code = iter.Get();
     int32_t offset = 0;
@@ -516,7 +513,7 @@ void EncodeDecodeKeyImpl(const absl::string_view src, std::string *dst) {
 size_t GetEncodedDecodedKeyLengthImpl(const absl::string_view src) {
   size_t size = src.size();
   for (ConstChar32Iterator iter(src); !iter.Done(); iter.Next()) {
-    static_assert(sizeof(uint32_t) == sizeof(char32),
+    static_assert(sizeof(uint32_t) == sizeof(char32_t),
                   "char32 must be 32-bit integer size.");
     uint32_t code = iter.Get();
     if ((code >= 0x3041 && code <= 0x3095) ||
